@@ -7,8 +7,9 @@ from .config import configure_app
 from .middleware import add_middlewares
 from . import default_settings
 
+
 def make_app():
-    app = Sanic("fdx", load_env="FPX_")
+    app = Sanic(__name__, load_env="FPX_")
     app.config.from_object(default_settings)
     app.config.from_envvar("FPX_CONFIG")
     CORS(app)
@@ -21,5 +22,7 @@ def make_app():
 def run_app():
     app = make_app()
     app.run(
-        host=app.config.HOST, port=app.config.PORT, debug=app.config.DEBUG,
+        host=app.config.HOST,
+        port=app.config.PORT,
+        debug=app.config.DEBUG,
     )
